package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0D```````````(`/@`!````D&X@``````!``````````/BM````
M`````````$``.``+`$``&P`:``8````$````0`````````!``"```````$``
M(```````:`(```````!H`@````````@``````````P````0```"H`@``````
M`*@"(```````J`(@```````5`````````!4``````````0`````````!````
M!``````````````````@`````````"```````(Q>````````C%X`````````
M$`````````$````%````D%X```````"0;B```````)!N(````````$@`````
M````2``````````0`````````0````8```"0I@```````)#&(```````D,8@
M``````#8`0```````-@!`````````!`````````!````!@```&BH````````
M:-@@``````!HV"```````#`"````````P08`````````$`````````(````&
M````N*8```````"XQB```````+C&(```````L`$```````"P`0````````@`
M````````4N5T9`0```"0I@```````)#&(```````D,8@``````#8`0``````
M`'`)`````````0````````!0Y71D!````(!9````````@%D@``````"`62``
M`````,P`````````S``````````$`````````%'E=&0&````````````````
M````````````````````````````````````````````````````!`````0`
M``#``@```````,`"(```````P`(@``````!(`````````$@`````````!```
M```````O;&EB97AE8R]L9"UE;&8N<V\N,0`````(````!`````$```!&<F5E
M0E-$`%!7$@`(````!`````0```!&<F5E0E-$```````(````!`````(```!&
M<F5E0E-$```````````````````````````````````````,````$@``````
M```````````````````=````$@`````````````````````````L````$@``
M```````````````````````V````(`````````````````````````"&````
M$@````````````````````````";````$@````````````````````````"G
M````$@````````````````````````"W````$@``````````````````````
M``##````$@````````````````````````#.````$@``````````````````
M``````#?````$@````````````````````````#R````$@``````````````
M`````````````0``$@`````````````````````````/`0``$@``````````
M```````````````>`0``$@````````````````````````!"`0``$@``````
M``````````````````!*`0``$@````````````````````````!W`0``$@``
M``````````````````````".`0``$@````````````````````````"4`0``
M$@````````````````````````"=`0``$@````````````````````````"E
M`0``$@````````````````````````#%`0``$@``````````````````````
M``#,`0``$@````````````````````````#5`0``$@``````````````````
M``````#<`0``$@````````````````````````#B`0``$@``````````````
M``````````#H`0``$@````````````````````````#O`0``$@``````````
M``````````````#V`0``$@````````````````````````#]`0``$@``````
M```````````````````%`@``$@`````````````````````````5`@``$@``
M```````````````````````:`@``$@````````````````````````"U`@``
M$@````````````````````````#``@``$@````````````````````````#/
M`@``$@````````````````````````#=`@``$@``````````````````````
M``#G`@``$@````````````````````````#R`@``$@``````````````````
M``````#[`@``$@`````````````````````````*`P``$@``````````````
M```````````>`P``$@`````````````````````````C`P``$@``````````
M```````````````K`P``$@`````````````````````````T`P``$@``````
M```````````````````\`P``$@````````````````````````!@`P``$@``
M``````````````````````!H`P``$@````````````````````````!M`P``
M$@````````````````````````!T`P``$@````````````````````````![
M`P``$@````````````````````````""`P``$@``````````````````````
M``")`P``$@````````````````````````"1`P``$@``````````````````
M``````"9`P``$@````````````````````````"@`P``$@``````````````
M``````````"G`P``$@````````````````````````"V`P``$@``````````
M``````````````"N`P``$@`.`(!Q(```````)P````````!;`0``$0`8`.#>
M(```````0`````````!^`0``$@````"S(`````````````````"6`@``$@`.
M`!"%(```````$PL```````!5`P``$@`.`"";(```````#0$````````Q````
M$@`.`."6(```````E@,```````!*````$0`8`"C?(````````0````````!B
M````$@```,"U(`````````````````!S````$@```-"U(```````````````
M``"J`0``$@`.`."#(```````'@`````````[`@``$@`.`(!R(```````P0``
M``````!\`@``$@`.`%!S(```````1@(```````")`@``$@`.`.!X(```````
M30H```````"C`@``$@`.``"$(```````"0$````````6````$@`.`)!N(```
M````!P$```````!M`0``$0`8`"#?(```````"``````````+`@``$0`6`(C8
M(```````"``````````O`@``$@`.`#"0(```````,P$```````!,`@``$@`.
M`+!Q(```````P0````````!B`@``$@`.`!!X(```````Q`````````!N`@``
M$@`.`#"#(```````K0````````!"`P``$@`.``"Q(```````3`$```````!,
M`P``$@`.`.":(```````/`````````!7````$0`8`-#>(```````!```````
M```L`0``$@`.`-"2(````````P0````````B`@``$@`.`.!W(```````)@``
M```````!````$0`6`&C8(```````"``````````D````$0`8`*#:(```````
M"`````````````(``@`"``$``0`!``$``0`!``$``0`!``$``0`!``(``@`"
M``(``@`"``(``@`"``(``@`#``(``@`"``(``@`"``(``0`!``$``0`!``$`
M!``$``(``P`"``(``@`"``,``@`"``(``@`"``(``@`"``(``@`!``(``0`!
M``$``0`!``$``0`!``$``0`!``$``0`"``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0"]`P``(````!`````!``(`T@,``"``````````L"AZ!P``!`#)
M`P```````+`H>@<```(`R0,``!````"U*'H'```#`-P#````````!P```#P`
M```(````&@````((,``!``P("`!0!"($``@```0`B```$`"($(``````"```
M``%@``"```""P(0`@$`!``Q!`!0`#0H`$8L```@\````/0````````!!````
M2@```%,```!6````P^4_+"!B9`=Z\$IKSMY'+4/ZUX=J?YI\"HH05X;YG('(
MU;)Q?JF<FR[%F[8@_^0.HN#[2?NA;&`R8MOMYA4#@X@'<--NQ=\?X*<""F:O
MS&:R`8MO:AJ>4!6,)<Q6I)N6U&34?.-'Q@&\4':>I]VC:U@```!8````````
M`!X`````````.@`````````F`````````````````````````#\````.````
M,0```"<````5`````````$(`````````````````````````````````````
M```````````````L````'````!<`````````!P``````````````````````
M``!#````/0``````````````````````````````'0`````````[````50``
M`%``````````2P`````````4````.0```$H```!/``````````````!-````
M`````#X```!$````4@```%8```!7````1P````````!3`````````$X````K
M````'P```$@`````````,P``````````````1@```%0````3````*```````
M`````````````#(`````````"````$````!!````````````````````````
M``````````````````````````````````0````````````````````,````
M"0```````````````@``````````````````````````````````````````
M````"@```!$````````````````````6````$````````````````````!D`
M```8``````````\````-````(P````L``````````````"H````M````````
M```````E````(````````````````````#0`````````+P````$````N````
M!0```!L`````````.````"(`````````(0```#8`````````&@```#P````I
M`````````#```````````P`````````D````20```!(`````````-0```$4`
M``!1````-P```$P```````````````8`````7U]P<F]G;F%M90!?:6YI=%]T
M;',`7W-T87)T`&%T97AI=`!E;G9I<F]N`&5X:70`;6%I;@!?2G9?4F5G:7-T
M97)#;&%S<V5S`%!,7V1O7W5N9'5M<`!03%]T:')?:V5Y`%!E<FQ?871F;W)K
M7VQO8VL`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?8W)O86M?;F]C;VYT97AT
M`%!E<FQ?9V5T7W-V`%!E<FQ?9W9?9F5T8VAP=@!097)L7VUG7W-E=`!097)L
M7VYE=UA3`%!E<FQ?;F5W6%-?9FQA9W,`4&5R;%]S869E<WES;6%L;&]C`%!E
M<FQ?<W9?<V5T<'8`4&5R;%]S=E]S971P=FX`4&5R;%]S>7-?:6YI=#,`4&5R
M;%]S>7-?=&5R;0!84U]);G1E<FYA;'-?4$%27T)/3U0`7U]E<G)O<@!?7W-T
M86-K7V-H:U]F86EL`%]?<W1A8VM?8VAK7V=U87)D`%]?<W1D97)R<`!A8V-E
M<W,`8F]O=%]$>6YA3&]A9&5R`&-L;W-E`&-L;W-E9&ER`&9P<FEN=&8`9G)E
M90!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!G971P:60`9V5T<'=U:60`
M9V5T=6ED`&QS965K`&QS=&%T`&UA;&QO8P!M96UC:'(`;65M8W!Y`&UE;6UO
M=F4`;6MD:7(`;7E?<&%R7W!L`&]P96X`;W!E;F1I<@!P87)?8F%S96YA;64`
M<&%R7V-L96%N=7``<&%R7V-U<G)E;G1?97AE8P!P87)?8W5R<F5N=%]E>&5C
M7W!R;V,`<&%R7V1I<FYA;64`<&%R7V5N=E]C;&5A;@!P87)?9FEN9'!R;V<`
M<&%R7VEN:71?96YV`'!A<E]M:W1M<&1I<@!P87)?<V5T=7!?;&EB<&%T:`!P
M97)L7V%L;&]C`'!E<FQ?8V]N<W1R=6-T`'!E<FQ?9&5S=')U8W0`<&5R;%]F
M<F5E`'!E<FQ?<&%R<V4`<&5R;%]R=6X`<'1H<F5A9%]A=&9O<FL`<'1H<F5A
M9%]G971S<&5C:69I8P!R96%D`')E861D:7(`<F5A9&QI;FL`<F5A;&QO8P!R
M;61I<@!S:&%?9FEN86P`<VAA7VEN:70`<VAA7W5P9&%T90!S<')I;G1F`'-T
M870`<W1R8VAR`'-T<F-M<`!S=')D=7``<W1R;&5N`'-T<FYC;7``<W1R;F-P
M>0!S=')S='(`<W1R=&]K`'5N;&EN:P!X<U]I;FET`&UE;7-E=`!L:6)T:'(N
M<V\N,P!&0E-$7S$N,`!L:6)C+G-O+C<`1D)31%\Q+C4`+W5S<B]L;V-A;"]L
M:6(O<&5R;#4O-2XS,B]M86-H+T-/4D4`;&EB<&5R;"YS;RXU+C,R`&QI8FTN
M<V\N-0!L:6)C<GEP="YS;RXU`&QI8G5T:6PN<V\N.0````````#@WB``````
M``4````]```````````````HWR````````4```!"```````````````@WR``
M``````4```!+``````````````#0WB````````4```!3``````````````"P
MV"````````<````"``````````````"XV"````````<````!````````````
M``#`V"````````<````#``````````````#(V"````````<````J````````
M``````#0V"````````<````^``````````````#8V"````````<````)````
M``````````#@V"````````<````7``````````````#HV"````````<````P
M``````````````#PV"````````<````M``````````````#XV"````````<`
M```<````````````````V2````````<````>```````````````(V2``````
M``<````1```````````````0V2````````<````V```````````````8V2``
M``````<````R```````````````@V2````````<````U```````````````H
MV2````````<````Y```````````````PV2````````<````S````````````
M```XV2````````<````Q``````````````!`V2````````<````2````````
M``````!(V2````````<````T``````````````!0V2````````<````N````
M``````````!8V2````````<````?``````````````!@V2````````<````W
M``````````````!HV2````````<````9``````````````!PV2````````<`
M```8``````````````!XV2````````<````X``````````````"`V2``````
M``<````;``````````````"(V2````````<````@``````````````"0V2``
M``````<````0``````````````"8V2````````<````5``````````````"@
MV2````````<````A``````````````"HV2````````<````:````````````
M``"PV2````````<````K``````````````"XV2````````<````3````````
M``````#`V2````````<````6``````````````#(V2````````<````B````
M``````````#0V2````````<````L``````````````#8V2````````<````Z
M``````````````#@V2````````<````4``````````````#HV2````````<`
M```O``````````````#PV2````````<````'``````````````#XV2``````
M``<````,````````````````VB````````<````=```````````````(VB``
M``````<````-```````````````0VB````````<````&```````````````8
MVB````````<````(```````````````@VB````````<````%````````````
M```HVB````````<````.```````````````PVB````````<```!#````````
M```````XVB````````<```!$``````````````!`VB````````<````I````
M``````````!(VB````````<````C``````````````!0VB````````<````D
M``````````````!8VB````````<````+``````````````!@VB````````<`
M```G``````````````!HVB````````<````H``````````````!PVB``````
M``<````E``````````````!XVB````````<````F``````````````"`VB``
M``````<````/``````````````"(VB````````<````*``````````````"0
MVB````````<````[`````````````````````````"5S)7,E<P!414U01$E2
M`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL
M960@*&5R<FYO/25I*0H`<&%R+0`E<R5S=&5M<"TE=25S`"X`4$523$E/`%!!
M4E]#3$5!3CT`5$U0`"5S)7-T96UP+25U+25U)7,`+P!015),-4Q)0@!54T52
M3D%-10!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0`O<')O8R]C
M=7)P<F]C+V9I;&4`4$%27T=,3T)!3%]$14)51P`O=&UP+P!P87)L`%!!4E]$
M14)51P!005)?0T%#2$4`4$%27T=,3T)!3%]435!$25(`)3`R>``E<R5S)7,E
M<P`E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@
M)7,@9F%I;&5D("AE<G)N;STE:2D*`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`$1Y
M;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!,1%],24)205)97U!!5$@`5$5-
M4`!435!$25(`+G!A<@!005)?5$5-4`!365-414T`,`!P97)L`"]P<F]C+R5I
M+R5S`%!!4E]#3$5!3@!005)?4U!!5TY%1``E<SH@<')I=F%T92!S=6)D:7)E
M8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R
M>2!Y;W5R(&]P97)A=&EO;BD*`%!!4E]04D]'3D%-10!005)?24Y)5$E!3$E:
M140`)7,E<V-A8VAE+25S)7,`4$%27T=,3T)!3%]414U0`"5S+R5S`#$`,2XP
M-3(`4$%27T=,3T)!3%]#3$5!3@!54T52`%!!5$@``%!%4DQ,24(`&``N+@!E
M=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@
M,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P
M87)?<&P["FUY("@D4$%27TU!1TE#+"`D<&%R7W1E;7`L("1P<F]G;F%M92P@
M0'1M<&9I;&4L("5-;V1U;&5#86-H92D["D5.1"![(&EF("@D14Y6>U!!4E]#
M3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A
M<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE
M.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q6U)E;6]V
M:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B72D["D9I;&4Z.D9I;F0Z.F9I;F1D
M97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E
M;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/
M(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%
M35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ
M9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^
M(#`L"BD["FUY("1F:6QE;F%M92`]("1T;7`M/F9I;&5N86UE.PIP<FEN="`D
M=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M
M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H
M96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@
M)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T;7`["F-H;6]D(#`W,#`L("1F:6QE
M;F%M93L*;7D@)&-M9"`]("(D9FEL96YA;64@/B]D978O;G5L;"`R/B8Q("8B
M.PIS>7-T96TH)&-M9"D["F]U=',H<7%;4W!A=VYE9"!B86-K9W)O=6YD('!R
M;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`D9FEL96YA;65=*3L*?0I]('T*
M0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN
M=&5R;F%L<SHZ4$%2.CI"3T]4.PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB
M.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM0
M05)?1$5"54=].PIM>2`E0V]N9FEG(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/
M(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>
M3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*
M7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@
M)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["FUY
M("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO8V%L("1324=[7U]705).
M7U]](#T@<W5B('M].PIO<&5N(%]&2"P@)SPZ<F%W)RP@)'!R;V=N86UE(&]R
M(&QA<W0["FUY("1B=68["FUY("1S:7IE(#T@+7,@)'!R;V=N86UE.PIM>2`D
M8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@)&UA9VEC7W!O<SL*:68@*"1S
M:7IE(#P]("1C:'5N:U]S:7IE*2!["B1M86=I8U]P;W,@/2`P.PI](&5L<VEF
M("@H;7D@)&T@/2`D<VEZ92`E("1C:'5N:U]S:7IE*2`^(#`I('L*)&UA9VEC
M7W!O<R`]("1S:7IE("T@)&T["GT@96QS92!["B1M86=I8U]P;W,@/2`D<VEZ
M92`M("1C:'5N:U]S:7IE.PI]"G=H:6QE("@D;6%G:6-?<&]S(#X](#`I('L*
M<V5E:R!?1D@L("1M86=I8U]P;W,L(#`["G)E860@7T9(+"`D8G5F+"`D8VAU
M;FM?<VEZ92`K(&QE;F=T:"@D4$%27TU!1TE#*3L*:68@*"AM>2`D:2`](')I
M;F1E>"@D8G5F+"`D4$%27TU!1TE#*2D@/CT@,"D@>PHD;6%G:6-?<&]S("L]
M("1I.PIL87-T.PI]"B1M86=I8U]P;W,@+3T@)&-H=6YK7W-I>F4["GT*;&%S
M="!I9B`D;6%G:6-?<&]S(#P@,#L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T
M+"`P.PIR96%D(%]&2"P@)&)U9BP@-#L*<V5E:R!?1D@L("1M86=I8U]P;W,@
M+2`T("T@=6YP86-K*").(BP@)&)U9BDL(#`["B1D871A7W!O<R`]('1E;&P@
M7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@
M("`@("`@("`@("`@("`@("`@("`@("`C(')E860@=&AE(&9I<G-T(")&24Q%
M(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0[
M"G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN
M86UE(#T@)&)U9CL*;W5T<RAQ<5M5;G!A8VMI;F<@1DE,12`B)&9U;&QN86UE
M(BXN+ETI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[
M.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]
M("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D
M8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF
M("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L
M*20O:2D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&-R8R1E>'0B+"`D
M8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65]
M(#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M
M97T@/2`D9G5L;&YA;64["GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S
M:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL
M96YA;64@/2!?<V%V95]A<R@B)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I
M.PIO=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*?0IE;'-E('L*)')E<75I
M<F5?;&ES='LD9G5L;&YA;65](#T*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@
M/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA
M;64L"GT["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS
M=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@
M)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2!D96QE=&4@)')E<75I
M<F5?;&ES='LD;6]D=6QE?2!O<B!R971U<FX["B1)3D-[)&UO9'5L97T@/2`B
M+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A
M;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I
M;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`B0V%N)W0@8W)E871E('1E;7`@9FEL
M93H@)"$B.PHD9F@M/F)I;FUO9&4H*3L*)&9H+3YP<FEN="@D:6YF;RT^>V)U
M9GTI.PHD9F@M/G-E96LH,"P@,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY
M("1F:6QE;F%M92`](%]S879E7V%S*"(D:6YF;RT^>V-R8WTN<&TB+"`D:6YF
M;RT^>V)U9GTI.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&5N86UE(&]R
M(&1I92!Q<5M#86XG="!R96%D("(D9FEL96YA;64B.B`D(5T["G)E='5R;B`D
M9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N)W0@9FEN9"!M
M;V1U;&4@)&UO9'5L92$B.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*
M<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U
M:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO
M861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE
M(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)
M3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@
M*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE
M.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O
M<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T
M>R1F:6QE;F%M97T["GT*;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P
M-"(["B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@
M("`@(R!S=&%R="!O9B!Z:7`*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D
M8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%2
M7T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R
M:71Y('!R;V)L96TI"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'
M?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T
M:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI
M8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@
M("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!
M4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?
M05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P
M87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2![
M"B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA
M<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*
M96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D
M,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D
M,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*
M)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD
M;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$[
M"GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@
M;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L
M<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`
M05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@
M)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I
M<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)0
M05(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS
M:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q
M=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@
M1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II
M<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@
M)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A
M73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII
M<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I
M(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R
M96%D:6YG('II<"!A<F-H:79E("(D<&%R(ET["GT*;7D@)65N=B`](&1O('L*
M:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N
M>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O
M7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*
M?3L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1P:"P@)SPZ<F%W)RP@
M)'!A<B!O<B!D:64@<7%;0V%N)W0@<F5A9"!P87(@9FEL92`B)'!A<B(Z("0A
M73L*;7D@)&)U9CL*<F5A9"`D<&@L("1B=68L(#0["F1I92!Q<5LB)'!A<B(@
M:7,@;F]T(&$@<&%R(&9I;&5=('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T
M(CL*8VQO<V4@)'!H.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)
M3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z
M.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W
M+`HI(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*
M)&9H+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII
M9B`H9&5F:6YE9"`D9&%T85]P;W,I('L*<F5A9"!?1D@L("1L;V%D97(L("1D
M871A7W!O<SL*?2!E;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*)&QO861E<B`]
M(#Q?1D@^.PI]"FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R
M(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0
M;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E
M<BP@)#`I.PI]"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*
M;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A;"`](&5V86P@)'9A
M;"!I9B`D=F%L(#U^("]>6R<B72\["FUY("1M86=I8R`](")?7T5.5E]005)?
M(B`N('5C*"1K97DI("X@(E]?(CL*;7D@)'-E="`](")005)?(B`N('5C*"1K
M97DI("X@(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PHD;6%G
M:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I
M*2D*?65G.PI]"B1F:"T^<')I;G0H)&QO861E<BD["FEF("@D8G5N9&QE*2![
M"G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO
M861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN
M8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I
M=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N
M9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,[
M"G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM>2`E9FEL97,["B1F
M:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S
M+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[
M;&EB7V5X='T[("`@("`@("`@(R!86%@@;&EB7V5X="!V<R!D;&5X="`_"FUY
M("5W<FET=&5N.PIF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I
M('L*;7D@*"1F:6QE+"`D;F%M92D["FEF("AD969I;F5D*&UY("1F8R`]("10
M05(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D9FEL92P@)&YA;64I
M(#T@*"1K97DL("1F8RD["GT*96QS92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN
M8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI)'QI*2!["B@D9FEL
M92P@)&YA;64I(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M
M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@)')E9B`]("1-;V1U
M;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL
M87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H
M(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F
M:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I
M9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I
M.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E<R(N+BY=+"!R968@
M)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0[
M"FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]
M"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY("1F:"P@)SPZ<F%W
M)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE(CH@)"%=.PHD
M8V]N=&5N="`](#PD9F@^.PIC;&]S92`D9F@["E!!4CHZ1FEL=&5R.CI0;V13
M=')I<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF
M("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX
M?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L
M>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*)&9H+3YP<FEN="@B1DE,
M12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P
M.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL
M("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N
M="D["F]U=',H<7%;5W)I='1E;B!A<R`B)&YA;64B72D["GT*?0HD>FEP+3YW
M<FET951O1FEL94AA;F1L92@D9F@I(&EF("1Z:7`["B1C86-H95]N86UE(#T@
M<W5B<W1R("1C86-H95]N86UE+"`P+"`T,#L*:68@*"$D8V%C:&5?;F%M92!A
M;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2!["FUY("1C='@@/2!$
M:6=E<W0Z.E-(02T^;F5W*#$I.PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)&]U
M=#L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92`D9F@["B1C86-H95]N86UE
M(#T@)&-T>"T^:&5X9&EG97-T.PI]"B1C86-H95]N86UE("X](")<,"(@>"`H
M-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD8V%C:&5?;F%M92`N/2`B0T%#
M2$4B.PHD9F@M/G!R:6YT*"1C86-H95]N86UE*3L*)&9H+3YP<FEN="AP86-K
M*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I*2D["B1F:"T^<')I
M;G0H)%!!4E]-04=)0RD["B1F:"T^8VQO<V4["F-H;6]D(#`W-34L("1O=70[
M"F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F
M:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET
M7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@
M07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN97<[("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`C($%R8VAI=F4Z.EII<"!O<&5R871E
M<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G
M<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F86EL960Z("0A73L*07)C:&EV93HZ
M6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z
M.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P
M<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q
M6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P<F]G;F%M92)=.PI!<F-H
M:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I.PIP=7-H($!005(Z
M.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@
M)'II<#L*)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;W5T<RAQ<5M<)$5.
M5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB72D["FEF("AD969I;F5D
M("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O
M:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN
M97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@
M/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE
M(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]
M+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD
M"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&
M:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N
M86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU
M;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<5M3:VEP<&EN9R`B)&UE;6)E
M<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M
M92)=*3L*?2!E;'-E('L*;W5T<RAQ<5M%>'1R86-T:6YG("(D;65M8F5R7VYA
M;64B('1O("(D9&5S=%]N86UE(ETI.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE
M3F%M960H)&1E<W1?;F%M92D["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF
M("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H
M97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G
M93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@
M<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F
M:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE
M(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H
M)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S
M96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R
M<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE
M.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP
M871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR
M97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G
M97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E
M('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q
M=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@
M17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*
M<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E
M($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE
M.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII
M<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@
M4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O
M;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D
M('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C
M86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ
M0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U
M<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ
M<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P
M87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6
M>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R
M;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!
M4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<
M5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A
M;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P
M=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE
M9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD
M=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE
M9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E
M<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-4
M14TG.PI]"B1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B
M)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N
M86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FEF("@A)$5.5GM005)?0TQ%
M04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PIO
M<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG
M="!R96%D("(D<')O9VYA;64B.B`D(5T["G-E96L@)&9H+"`M,3@L(#(["FUY
M("1B=68["G)E860@)&9H+"`D8G5F+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(
M12(I('L*<V5E:R`D9F@L("TU."P@,CL*<F5A9"`D9F@L("1B=68L(#0Q.PHD
M8G5F(#U^(',O7#`O+V<["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC
M86-H92TD8G5F(CL*?0IE;'-E('L*;7D@)&1I9V5S="`](&5V86P*>PIR97%U
M:7)E($1I9V5S=#HZ4TA!.PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q
M*3L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M92!O<B!D:64@<7%;
M0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PHD8W1X+3YA9&1F:6QE*"1F
M:"D["F-L;W-E*"1F:"D["B1C='@M/FAE>&1I9V5S=#L*?2!\?"`D;71I;64[
M"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TD9&EG97-T(CL*
M?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PHD
M<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"(["GT*)$5.5GM0
M05)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["FQA
M<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%
M3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W-A=F5?87,@>PIM>2`H
M)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]
M("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM
M>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;W!E;B!M>2`D9F@L("<^
M.G)A=R<L("1T96UP;F%M92!O<B!D:64@<7%;0V%N)W0@=W)I=&4@(B1T96UP
M;F%M92(Z("0A73L*<')I;G0@)&9H("1C;VYT96YT<SL*8VQO<V4@)&9H.PIC
M:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M
M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D[
M"GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF
M("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/
M1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA
M;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G
M;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B
M<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L
M:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X
M*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N
M(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*
M?0II9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M
M92`N/2`D0V]N9FEG>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D
M:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]
M*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q
M("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<
M120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G
M;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG
M>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL**"@D<')O9VYA;64@
M/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M
M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I
M>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'
M3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@
M/"`P*2!["B1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE
M(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ
M9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z
M.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^
M(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[
M7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS
M=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]
M*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,
M25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)5
M1R!#04-(12!04D]'3D%-12`I("D@>PID96QE=&4@)$5.5GLG4$%27R<N)%]]
M.PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.
M5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES
M=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM>2`D<&%R7V-L96%N(#T@
M(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*:68@*"1%3E9[
M4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*96QS:68@
M*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PIM>2`D=F%L=64@
M/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PHD
M14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]
M*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H
M)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT
M(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP
M=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD
M7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET
M96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA
M9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I
M;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7%;<&%R+G!L
M.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H
M(&9I;&4@;W(@9&ER96-T;W)Y7&Y="G5N;&5S<R`M92`D<')O9VYA;64["F1O
M("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)
M5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@
M)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO
M7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?
M7T524D]2.PHQ.PI?7T5.1%]?"@!015),-4]05``M90`M+0!005)?5$U01$E2
M`%!!4CHZ4&%C:V5R.CI615)324].`&9I;&4`.@```````````````"XO<&5R
M;'AS:2YC``````!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(```
M```````````````````O&R```````*T:(```````````````````````````
M`.@<(```````X1H@````````````````````````````_MRZF`````!V5#(0
M``````$C16<`````B:O-[P````#_____`````/____\`````````P```````
M``#```````$;`SO,````&````!`5``#H````(!8``!`!```P%P``0`$````8
M``!H`0``,!@``(@!````&0``L`$``-`9``#8`0``(!P```@"``!@'@``.`(`
M`)`>``!8`@``8!\``(@"``"P*0``N`(``&`J``#@`@``@"H```@#``"0*P``
M0`,``+`V``!P`P``\#<``*@#``!0.0``V`,``&`]```(!````$$``#@$``!@
M00``6`0``*!!``!X!```L$(``*@$``"`5P``V`0````````4``````````%Z
M4@`!>!`!&PP'")`!```D````'````"`4```'`0```$$.$(8"0PT&2H,'C`:-
M!8X$CP,`````+````$0````(%0```@$```!!#A"&`D,-!DJ#!XP&C06.!(\#
M`O,,!P@`````````)````'0```#H%0``6P````!!#A"&`D,-!D*#`V<,!PA%
M#`80`````!P```"<````D!8``"<`````00X0A@)##09>#`<(````)````+P`
M``"@%@``P0````!!#A"&`D,-!DJ#!(X#`JT,!PA!#`80`"0```#D````2!<`
M`,$`````00X0A@)##09*@P2.`P*M#`<(00P&$``L````#`$``/`7``!&`@``
M`$$.$(8"0PT&4(,'C`:-!8X$CP,"\0P'"$$,!A`````L````/`$``!`:```Q
M`@```$$.$(8"0PT&38,'C`:-!8X$CP,#_0$,!PA!#`80```<````;`$``"`<
M```F`````$$.$(8"0PT&80P'"````"P```",`0``,!P``,0`````00X0A@)#
M#09#@P2.`P*2#`<(10P&$%X,!PA!#`80`"P```"\`0``T!P``$T*````00X0
MA@)##09-@P>,!HT%C@2/`P,R"@P'"$4,!A```"0```#L`0``\"8``*T`````
M00X0A@)##09'@P:,!8X$CP,"H0P'"``D````%`(``'@G```>`````$$.$(8"
M0PT&50P'"$$,!A!##`<(````-````#P"``!P)P``"0$```!!#A"&`D,-!D>#
M!HP%C@2/`P*L#`<(00P&$%`,!PA%#`80```````L````=`(``$@H```3"P``
M`$$.$(8"0PT&4(,'C`:-!8X$CP,#'@4,!PA!#`80```T````I`(``#@S```S
M`0```$$.$(8"0PT&2H,'C`:-!8X$CP,#$0$,!PA!#`8040P'"````````"P`
M``#<`@``0#0``%\!````00X0A@)##090@P>,!HT%C@2/`P-%`0P'"$$,!A``
M`"P````,`P``<#4```,$````00X0A@)##090@P>,!HT%C@2/`P.?`PP'"$$,
M!A```"P````\`P``4#D``)8#````00X0A@)##09-@P>,!HT%C@2/`P-E`PP'
M"$$,!A```!P```!L`P``P#P``%T`````00X0A@)##08"5`P'"```'````(P#
M````/0``/`````!!#A"&`D,-!G<,!P@````L````K`,``"`]```-`0```$$.
M$(8"0PT&2H,'C`:-!8X$CP,"_@P'"``````````L````W`,````^``#'%```
M`$$.$(8"0PT&4(,'C`:-!8X$CP,#K10,!PA!#`80```L````#`0``*!2``!,
M`0```$$.$(8"0PT&1X,&C`6.!(\#`SP!#`<(`````````````````````%5(
MB>5!5T%6055!5%-028G^3(L_26/'3(TDQTF#Q!!(@SWI:P```'4'3(DEX&L`
M`$F#Q@A%A?]^"$F+!DB%P'4?N+C&(`!(A<!T+TB)]^C=0P``Z8P````/'X0`
M`````$B)!7%I``!(@\`!#[9(_X3)=,Z`^2]TZ.OMO@````!!O0````!).?5S
M5;@!````#Z*)UT&)R#'`#Z*[`````+D`````@_@'<@DQR;@'````#Z)!@WT(
M)74=28M%`$B)1=!$B<:)VD'_51"^`````$B+3=!(B0%)@\4823GU<JOH7$,`
M`$2)_TR)]DR)XN@>````1(G_3(GV3(GBZ%`G``")Q^A)0P``9@\?A```````
M54B)Y4%7059!54%44U!(B570N+C&(`!(A<`/A=,```!)B?=!B?R_L'`@`.CP
M0@``N)!N(`"[D&X@`$@IPTR-:P=(A=M(B=A)#TC%2,'X`W1"13'VZR%F+@\?
MA```````28/&`4B%VTB)V$D/2,5(P?@#23G&<QQ*BP3UD&X@`$B#^`)RVT2)
MYTR)_DB+5=#_T.O-Z%!"``"XD&X@`$&^D&X@`$DIQDV-;@=-A?9,B?!)#TC%
M2,'X`W0Y,=OK&6:02(/#`4V%]DR)\$D/2,5(P?@#2#G#<QQ(BP3=D&X@`$B#
M^`)RVT2)YTR)_DB+5=#_T.O-2(/$"%M!7$%=05Y!7UW#9BX/'X0```````\?
M0`!52(GE4U"YD&X@`+B0;B``2"G(2(U8!TB%P$B)P4@/2,M(P?D#=0M(@\0(
M6UWIND$``$B%P$@/2=A(P?L#ZP:02(7;=.)(BP3=B&X@`$B#P_](@_@"<NG_
MT.OES,S,S,Q52(GE@#UE9P```'4H#Q\`2(L-46<``$B+`4B%P'0/2(/!"$B)
M#3YG``#_T.OBQ@4[9P```5W#9@\?A```````54B)Y4B#/515````=!*X````
M`$B%P'0(O[#&(`!=_^!=P\S,S,S,S,S,S,S,S,S,54B)Y8L]1FT``.AA00``
MOL0;(`"Z`+,@`+G`6"``2(G'7>EI00``9@\?A```````54B)Y4%64TB!["`(
M``!(BP4;;0``2(E%Z.A200``13'V2(V]X/O__[X8'"``N:Y8(`")PC'`Z$5!
M``"%P'AA2(V]X/O__TB-M=#W__^Z``0``.@Y00``2(G#A=MX/TC!XR!(OP``
M```!````2`'?2,'_(.@H00``2(7`="!)B<9(P?L@2(VUT/?__TB)QTB)VN@:
M00``0<8$'@#K`T4Q]DB+!8EL``!(.T7H=0],B?!(@<0@"```6T%>7</H_T``
M`&8N#Q^$```````/'T0``%5(B>5!5E-(@>P@"```2(L%2VP``$B)1>CH@D``
M`$4Q]DB-O>#[__^^&!P@`+FN6"``B<(QP.AU0```A<!X84B-O>#[__](C;70
M]___N@`$``#H:4```$B)PX7;>#](P>,@2+\``````0```$@!WTC!_R#H6$``
M`$B%P'0@28G&2,'[($B-M=#W__](B<=(B=KH2D```$'&!!X`ZP-%,?9(BP6Y
M:P``2#M%Z'4/3(GP2('$(`@``%M!7EW#Z"]```!F+@\?A```````#Q]$``!5
M2(GE05=!5D%505132('L^`0``$B)\TF)_DB+!6]K``!(B4703(LM)&<``$V%
M[0^$?0```+@!'"``9@\?1```#[8(A,ET"X#Y/70&2(/``>ON2(F=Z/K__TF+
M70!(A=MT5;D!'"``*<A,8_A)@\4(13'DZQAF+@\?A```````D$F+70!)@\4(
M2(7;="V^`1P@`$B)WTR)^NB3/P``A<!UWT*`/#L]==A.C20[28/$`>L(13'D
MZPI%,>1(BYWH^O__3(GWOB\```#H<C\``$B%P'0SOXT<(`!,B?;H<`$``$B+
M!:EJ``!(.T70#X50`0``3(GP2('$^`0``%M!7$%=05Y!7UW#3(GWZ$(_``!)
MB<>^LU@@`$B)W^A"/P``2(7`=+!)B<5!@\<!2(V=T/O__^LE9BX/'X0`````
M``\?`+ZS6"``,?_H%#\``$F)Q4B%P`^$>____T&`?0``N*T:(`!,#T3H387D
M=`],B>=,B>[H^CX``(7`=,9,B>_HSCX``(G!@\'_2&/)08!\#0`O=2!(@\$!
M2(G(#Q^``````$'&1`7_`$&`?`7^+TB-0/]T[D0!^#T`!```#XT3____OE`:
M(`"YUAH@`$B)WTR)ZDV)\#'`Z`8^``!(B=](C;7P^O__Z)<^``"%P`^%3___
M_P^WA0C[__\E`/```#T`@```#X4X____2(G?O@$```#H>SX``(7`#X4C____
M2(V=T/O__[^-'"``2(G>Z!\```!(B=_H9SX``$F)QNF?_O__Z-H]``!F+@\?
MA```````54B)Y4%7059!54%44TB#[!A)B?U(C7X!@#X]2`]%_DB)?<CHV#T`
M`$B)1=!,BS7-9```387M=!I-A?9T%4R)Z`^V"(3)=!"`^3UT"TB#P`'K[DF+
M!NM]38L^387_#X2,````1"GH2&/83(E]P$V)].L<9BX/'X0```````\?0`!-
MBWPD"$F#Q`A-A?]T0DR)_TR)[DB)VNA$/0``A<!UX$&`/!\]==E,`?M(@\,!
M2(G?Z$H]``!(.T702(M5R`^#2P$``$TI]$G![`/IF````$B+1<!%,>1(A<!T
M%@\?0`!+@WSF"`!-C60D`77SZP-%,>2`/2]H```!18GG=21*C33]$````$R)
M]^A2/0``28G&2(D%Z&,``$B%P'5"Z=X```#&!?]G```!2HT\_1````#H>CP`
M`$B%P`^$P0```$B)PTJ-%/T`````2(G'3(GVZ!L]``!(B1VD8P``28G>2\=$
M_@@`````3(GH#Q]$```/M@B$R70+@/D]=`9(@\`!Z^Y$*>A(F$B+3=!(C3P!
M2(/'`N@8/```2(MUR$ECS$F)!,Y(A<!T6$B+!5%C``!(BP3(9BX/'X0`````
M``\?`$$/MDT`B`B$R70/@/D]=`I)@\4!2(/``>OFQ@`]N0$```!F+@\?A```
M````#Q]```^V5`[_B!0(2(/!`832=?!(@\086T%<05U!7D%?7<,QP&8N#Q^$
M```````/'T0```^V#`*(#`-(@\`!A,EU\>O/9BX/'X0```````\?1```54B)
MY4B)^$B-3P'K"@\?`$B)R$B#P0$/ME'_@/HO=/"$TG7O7<-F+@\?A```````
M54B)Y4%64TB%_P^$@````$B)^T2*-T6$]G1U2(G?Z&T[``!(C0P82(/!_P\?
M1```2#G9=DV`.2](C4G_=/+K"4B-2/^`."]T"$B)R$@YV7?O2#G8=#1(@\#_
M9@\?1```2(G"2"G:=@F`."](C4#_=.](C4("2#T`!```=B%%,?;K,TB)R$@Y
MV'7,08#^+W4MOZT:(`!;05Y=Z4([``!(@\(!0;ZPVB``O[#:(`!(B=[H6SL`
M`$R)\%M!7EW#O]8:(`#KT68N#Q^$``````!FD%5(B>5!5T%6055!5%-(@^PX
M2(L%Z&4``$B)1=`/*`7=W___#RE%L`\H!<+?__\/*46@9L=%P```3(LE@6$`
M`$V%Y`^$J@D``$&_V!H@`+C8&B``9BX/'X0```````\?``^V"(3)=!F`^3UT
M%$B#P`'K[F8N#Q^$```````/'T``38LL)$V%[0^$\P```$0I^$QC\$R)X^L9
M#Q^$``````!,BVL(2(/#"$V%[0^$SP```+[8&B``3(GO3(GRZ-\Y``"%P'7;
M0X!\-0`]==-,*>-(P>L#2&/#28T$Q$B#P`B02(L(2(E(^$B#P`A(A<EU\$R+
M)<E@``!-A>0/A4[____I[0@``&8N#Q^$``````"0N?,<(``IR$QC\$R)X^L2
MD$R+>PA(@\,(387_#X3_````OO,<(`!,B?],B?+H7SD``(7`==M#@#PW/774
M3"GC2,'K`TACPTF-!,1(@\`(9I!(BPA(B4CX2(/`"$B%R77P3(LE26```$V%
MY`^$<@@``+CS'"``9BX/'X0``````)`/M@B$R709@/D]=!1(@\`!Z^YF+@\?
MA```````#Q]``$V+/"1-A?\/A5/____K<9"Y?U@@`"G(3&/P3(GCZQ*03(M[
M"$B#PPA-A?\/A/\```"^?U@@`$R)_TR)\NBO.```A<!UVT.`/#<]==1,*>-(
MP>L#2&/#28T$Q$B#P`AFD$B+"$B)2/A(@\`(2(7)=?!,BR697P``387D#X3"
M!P``N']8(`!F+@\?A```````D`^V"(3)=!F`^3UT%$B#P`'K[F8N#Q^$````
M```/'T``38L\)$V%_P^%4____^MQD+FO&B``*<A,8_!,B>/K$I!,BWL(2(/#
M"$V%_P^$_P```+ZO&B``3(G_3(GRZ/\W``"%P'7;0X`\-SUUU$PIXTC!ZP-(
M8\-)C03$2(/`"&:02(L(2(E(^$B#P`A(A<EU\$R+)>E>``!-A>0/A!('``"X
MKQH@`&8N#Q^$``````"0#[8(A,ET&8#Y/7042(/``>ON9BX/'X0```````\?
M0`!-BSPD387_#X53____ZW&0N9H<(``IR$QC\$R)X^L2D$R+>PA(@\,(387_
M#X3_````OIH<(`!,B?],B?+H3S<``(7`==M#@#PW/7743"GC2,'K`TACPTF-
M!,1(@\`(9I!(BPA(B4CX2(/`"$B%R77P3(LE.5X``$V%Y`^$8@8``+B:'"``
M9BX/'X0``````)`/M@B$R709@/D]=!1(@\`!Z^YF+@\?A```````#Q]``$V+
M/"1-A?\/A5/____K<9"Y+AP@`"G(3&/P3(GCZQ*03(M["$B#PPA-A?\/A/\`
M``"^+AP@`$R)_TR)\NB?-@``A<!UVT.`/#<]==1,*>-(P>L#2&/#28T$Q$B#
MP`AFD$B+"$B)2/A(@\`(2(7)=?!,BR6)70``387D#X2R!0``N"X<(`!F+@\?
MA```````D`^V"(3)=!F`^3UT%$B#P`'K[F8N#Q^$```````/'T``38L\)$V%
M_P^%4____^MQD+D!'"``*<A,8_!,B>/K$I!,BWL(2(/#"$V%_P^$_P```+X!
M'"``3(G_3(GRZ.\U``"%P'7;0X`\-SUUU$PIXTC!ZP-(8\-)C03$2(/`"&:0
M2(L(2(E(^$B#P`A(A<EU\$R+)=E<``!-A>0/A`(%``"X`1P@`&8N#Q^$````
M``"0#[8(A,ET&8#Y/7042(/``>ON9BX/'X0```````\?0`!-BSPD387_#X53
M____ZW&0N20<(``IR$QC\$R)X^L2D$R+>PA(@\,(387_#X3_````OB0<(`!,
MB?],B?+H/S4``(7`==M#@#PW/7743"GC2,'K`TACPTF-!,1(@\`(9I!(BPA(
MB4CX2(/`"$B%R77P3(LE*5P``$V%Y`^$4@0``+@D'"``9BX/'X0``````)`/
MM@B$R709@/D]=!1(@\`!Z^YF+@\?A```````#Q]``$V+/"1-A?\/A5/____K
M<9"Y.AL@`"G(3&/P3(GCZQ*03(M["$B#PPA-A?\/A/\```"^.AL@`$R)_TR)
M\NB/-```A<!UVT.`/#<]==1,*>-(P>L#2&/#28T$Q$B#P`AFD$B+"$B)2/A(
M@\`(2(7)=?!,BR5Y6P``387D#X2B`P``N#H;(`!F+@\?A```````D`^V"(3)
M=!F`^3UT%$B#P`'K[F8N#Q^$```````/'T``38L\)$V%_P^%4____^MQD+E$
M&R``*<A,8_!,B>/K$I!,BWL(2(/#"$V%_P^$'P$``+Y$&R``3(G_3(GRZ-\S
M``"%P'7;0X`\-SUUU$PIXTC!ZP-(8\-)C03$2(/`"&:02(L(2(E(^$B#P`A(
MA<EU\$R+)<E:``!-A>0/A/("``"X1!L@`&8N#Q^$``````"0#[8(A,ET&8#Y
M/7042(/``>ON9BX/'X0```````\?0`!-BSPD387_#X53____Z8X```!F+@\?
MA```````#Q]``+F-'"``*<A,8_!-B?U,B>/K'V8N#Q^$```````/'T``3(MK
M"$B#PPA-A>T/A(P```"^C1P@`$R)[TR)\N@/,P``A<!UVT.`?#4`/7733"GC
M2,'K`TACPTF-!,1(@\`(D$B+"$B)2/A(@\`(2(7)=?!,BR7Y60``387D#X0B
M`@``N(T<(`!F+@\?A```````D`^V"(3)=!F`^3UT%$B#P`'K[F8N#Q^$````
M```/'T``38L\)$V%_P^%0____[@>&R``9BX/'X0```````\?0``/M@B$R70+
M@/D]=`9(@\`!Z^Y-A?]T6;D>&R``*<A,8_!)C5PD".L4#Q^$``````!,BSM(
M@\,(387_=#2^'AL@`$R)_TR)\N@T,@``A<!UX$.`/#<]==E+C30W2(/&`;\Z
M&R``Z#?T__],BR4P60``387D#X19`0``N$X;(`!FD`^V"(3)=`N`^3UT!DB#
MP`'K[DV+/"1-A?]T7KE.&R``*<A,8_!)C5PD".L0#Q]``$R+.TB#PPA-A?]T
M-+Y.&R``3(G_3(GRZ+0Q``"%P'7@0X`\-SUUV4N--#=(@\8!OXY8(`#HM_/_
M_TR+);!8``!-A>0/A-D```"XN1P@`&:0#[8(A,ET"X#Y/70&2(/``>ON38L\
M)$V%_W1/N;D<(``IR$QC\$F-7"0(38G]ZPV03(LK2(/#"$V%[70NOKD<(`!,
MB>],B?+H-#$``(7`=>!#@'PU`#UUV$N--"Y(@\8!OP$<(`#ICP```+C7'"``
MD`^V"(3)=`N`^3UT!DB#P`'K[DV%_W1+N=<<(``IR$QC\$F#Q`CK%F8/'X0`
M`````$V+/"1)@\0(387_="6^UQP@`$R)_TR)\NC#,```A<!UWT.`/#<]==A+
MC30W2(/&`>LB2+A005)?0TQ%04@S1;$/MTVY2('Q3CT``$@)P74.2(UUN[\D
M'"``Z*+R__](BP7;6P``2#M%T'4=OYH<(`"^SQP@`$B#Q#A;05Q!74%>05]=
MZ7CR___H0S````\?`%5(B>5!5T%605131(LU3E4``$&#_O\/A84```!,BR5-
M5P``13'V387D=&^X)!P@``^V"(3)=`N`^3UT!DB#P`'K[DF+'"1(A=MT3[DD
M'"``*<A,8_A)@\0(ZQ(/'T0``$F+'"1)@\0(2(7;="V^)!P@`$B)WTR)^NC3
M+P``A<!UWT*`/#L]==A"BD0[`83`=`E%,?8\,$$/E<9$B36_5```1(GP6T%<
M05Y!7UW##Q\`54B)Y>A',```B<?H4#```$B%P'0%2(L`7<,QP%W#9I!52(GE
M05=!5D%44TF)_DR+)8M6``!-A>0/A)H```"XX!L@`&8N#Q^$```````/'P`/
MM@B$R70+@/D]=`9(@\`!Z^Y)BQPD2(7;=&VYX!L@`"G(3&/X28/$".L2#Q]$
M``!)BQPD28/$"$B%VW1+ON`;(`!(B=],B?KH`R\``(7`==]"@#P[/77820'?
M28/'`4R)_^@)+P``2(7`=!Q(B<-,B?],B?;HIB\``$B%P'0>6T%<05Y!7UW#
MO^`;(`!,B?9;05Q!7D%?7>G3\/__3(GWZ,LN``!(C3P#2(/'`NAN+@``2(G#
MOE`:(`"YLU@@`$B)QTR)\DV)^#'`Z#$N``"_X!L@`$B)WNNW#Q^``````%5(
MB>5!5T%6055!5%-(@>RH@```28G\2(L%LED``$B)1=`/5\`/*46@#RE%L`\I
M1<!(QT6@CE@@`$C'1:CU&R``2,=%L%<:(`!(QT6X\!L@`$C'1<#!&B``2(L=
M,%4``$B%VP^$A@```+@!'"``9I`/M@B$R70+@/D]=`9(@\`!Z^Y,BSM-A?]T
M9;D!'"``*<A,8_!(@\,(ZQ)F#Q]$``!,BSM(@\,(387_=$.^`1P@`$R)_TR)
M\NBT+0``A<!UX$.`/#<]==E#@'PW`0!T($N-'#=(@\,!2(G?Z!'^__](B=_H
M^2T``$F)QND>!```3(FE2'___^@E+@``B<?H+BX``$B%P'0,2(L`2(7`#X70
M````13'D9BX/'X0``````$F#_`(/A+<```!(BQU?5```2(7;#X26````3HLT
MY2!9(`!,B?!F+@\?A```````D`^V"(3)=!F`^3UT%$B#P`'K[F8N#Q^$````
M```/'T``3(LK387M=%A$*?!,8_A(@\,(ZQAF+@\?A```````9I!,BRM(@\,(
M387M=#1,B>],B?9,B?KHQBP``(7`=>)#@'P]`#UUVD.`?#T!`'022XT\+TB#
MQP'H%2T``.L%#Q\`,<!)@\0!2(7`#X1!____ZP(QP$B%P$&^"AP@`$P/1?!,
MB??HF"P``$B-/`!(@\<!Z#LL``!)B<=!B@:$P'0S28/&`4R)^V8N#Q^$````
M```/MM"^8!L@`$B)WS'`Z.XK``!(@\,"00^V!DF#Q@&$P'7>3(F]0'___T&\
MCE@@`$4Q]NLN2(G?O@(```#H;RP``(7`#X3Q````#Q^``````$Z+9/6H28/&
M`4V%Y`^$[````$R++0=3``!-A>UTXDR)X&8N#Q^$```````/'T0```^V"(3)
M=!F`^3UT%$B#P`'K[F8N#Q^$```````/'T``28M=`$B%VW2G1"G@3&/X28/%
M".L89BX/'X0``````)!)BUT`28/%"$B%VW2#2(G?3(GF3(GZZ'4K``"%P'7A
M0H`\.SUUVD*`?#L!``^$7O___TP!^TB#PP%(B=](C;5P?___Z"@L``"%P`^%
M0/___P^WA8A___\E`/```#T`H```#X0-____#[?`/0!````/A/_^___I%O__
M_TB)W^A^*P``2(G#2(7`#X5_````2<?'\/___TR-M7!___\/'T``387_=&9)
MBY\062``@#L`=%I(B=],B?;HM"L``(7`=!`QVTF#QPA(A=MTU>M`#Q\`#[>%
MB'___R4`\```/0"@``!T"@^WP#T`0```==-(B=^^`@```.CV*@``A<!UPDB)
MW^CZ*@``2(G#Z[<QVTB)W^B;*@``28G&3(N]0'___TR)_^B)*@``1`'P!00$
M``!,8_!,B??H)BH``$F)Q+YE&R``N=8:(`!!N)H:(`!(B<=(B=I-B?DQP.CC
M*0``3(GGOL`!``#H%BL``(/X_W4.Z!PK``"#.!$/A=8```!(C;5P?___3(GG
MZ.0J``"%P'5Z#[>=B'___XG8)0#P```]`$```'5E1(N]C'___^B/*@``03G'
M=52!X_\!``"!^\`!``!U1DR)]^B4*0``28G&3(LMVE```$V%[0^$$P$``+CM
M'"``9BX/'X0``````&:0#[8(A,D/A(L```"`^3T/A((```!(@\`!Z^9(BST?
M50``2(N%2'___TB+$$4Q]KXZ'"``3(GA,<#H<RH``$B+!;Q4``!(.T70#X7P
M!0``3(GP2('$J(```%M!7$%=05Y!7UW#3(L]UE0``$B+A4A___](BQCH)RH`
M`$2+`$4Q]KY?&B``3(G_2(G:3(GA,<#H'"H``.NG28M=`$B%VW1CN>T<(``I
MR$QC^$F#Q0CK#I!)BUT`28/%"$B%VW1%ONT<(`!(B=],B?KHTR@``(7`==]"
M@#P[/7782HT\.TB#QP%(BX5(?___2(L8Z"$I``!(B=](B<;H=NC__TF)QTB%
MP'4*2(N%2'___TR+.$R)_^BL*```2(G#@_L$?!U(8\-)C3P'2(/'_+XU&R``
MZ*\H``"%P`^$IP```(L5<4T``(/Z_P^%#P$``$R++7%/```QTDV%[0^$]P``
M`+@D'"``D`^V"(3)=`N`^3UT!DB#P`'K[DF+70!(A=L/A-(```!,B;U(?___
MN20<(``IR$QC^$F#Q0CK$4F+70!)@\4(2(7;#X2A````OB0<(`!(B=],B?KH
MZ2<``(7`==M"@#P[/7740HI$.P&$P$R+O4A___^Z`````'1Z,=(\,`^5PNMQ
M@_L$="!(P>,@2+@`````^____T@!V$C!^"!!@#P'+P^%-/___TB+A4A___](
MBU@(2(7;#X0@____2(G?Z)\G``!(@_@$#X(.____2(T\`TB#Q_R^_!L@`.BC
M)P``A<!,#T3[Z?'^__],B[U(?___,=*)%5E,``"%T@^$H0```+\D'"``OL\<
M(`#H4NG__^C-)@``OI\:(`"YUAH@`$&Y\AP@`$R)]TR)XD&)P#'`Z+TF``!,
MB?>^P`$``.CP)P``@_C_#X5S`P``NP$```#H[2<``(,X$0^%8`,``.A_)@``
M2,<$)/(<(`"^Q1H@`+G6&B``3(GW3(GB08G`08G9,<#H:B8``$R)][[``0``
MZ)TG``"#PP&#^/]TL^D<`P``3(G_,?8QP.BT)P``A<`/A$O___]!B<>)QTC'
MQN[___^Z`@```.BF)P``2(VU<'___[H&````1(G_Z*(G``"`O7!___\`=5V`
MO7%___]#=52`O7)___]!=4N`O7-___]#=4*`O71___](=3F`O75___]%=3!$
MB?](Q\;&____N@(```#H2"<``$B-G7!___^Z*0```$2)_TB)WNA!)P``Z5@"
M``!$B?\Q]C'2Z"`G```QP.A)#0``28G%2(VU<'___[H`@```1(G_Z!(G``"%
MP'XH2(V=<'___TR)[TB)WHG"Z%H-``"Z`(```$2)_TB)WNCJ)@``A<!_WT2)
M_^CN)@``2(V]4'___TR)[N@/(P``#[:54'___TB-G7#___^^8!L@`$B)WS'`
MZ"(E``!(C;UR____#[:547___[Y@&R``,<#H""4``$B-O73___\/MI52?___
MOF`;(``QP.CN)```2(V]=O___P^VE5-___^^8!L@`#'`Z-0D``!(C;UX____
M#[:55'___[Y@&R``,<#HNB0``$B-O7K___\/MI55?___OF`;(``QP.B@)```
M2(V]?/___P^VE59___^^8!L@`#'`Z(8D``!(C;U^____#[:55W___[Y@&R``
M,<#H;"0``$B-?8`/MI58?___OF`;(``QP.A5)```2(U]@@^VE5E___^^8!L@
M`#'`Z#XD``!(C7V$#[:56G___[Y@&R``,<#H)R0``$B-?88/MI5;?___OF`;
M(``QP.@0)```2(U]B`^VE5Q___^^8!L@`#'`Z/DC``!(C7V*#[:577___[Y@
M&R``,<#HXB,``$B-?8P/MI5>?___OF`;(``QP.C+(P``2(U]C@^VE5]___^^
M8!L@`#'`Z+0C``!(C7V0#[:58'___[Y@&R``,<#HG2,``$B-?9(/MI5A?___
MOF`;(``QP.B&(P``2(U]E`^VE6)___^^8!L@`#'`Z&\C``!(C7V6#[:58W__
M_[Y@&R``,<#H6",``,9%F`"^JAP@`+G6&B``0;GR'"``3(GW3(GB28G8,<#H
M-",``$R)Y^C<)```OP$<(`!,B?;HC^7__TR)]^CG\___Z?_Y___H32,``&8N
M#Q^$```````/'P!52(GE05=!5D%505134$F)_.C*Y___9BX/'X0``````$F)
MQTB#P`$/MDC_@/DO=/"$R77O1(LM)4@``$&#_?]T#DV%Y`^%I0```.G"````
M3(LU&DH``$4Q[4V%]@^$@0```+@D'"``9@\?A```````#[8(A,ET"X#Y/70&
M2(/``>ON28L>2(7;=%E,B670N20<(``IR$QCX$F#Q@CK#F:028L>28/&"$B%
MVW0SOB0<(`!(B=],B>+HE"(``(7`=>!"@#PC/7790HI$(P&$P$R+9=!T#T4Q
M[3PP00^5Q>L$3(MET$2)+79'``!-A>1T(D6%[70=08`\)`!T%KZ:&B``N@0`
M``!,B?_H0R(``(7`=`](@\0(6T%<05U!7D%?7<-,B>=(@\0(6T%<05U!7D%?
M7>L-9BX/'X0```````\?`%5(B>5!5T%6055!5%-(@>SH````2(L%54T``$B)
M1=!(A?\/A!,!``!)B?R`/P`/A`<!``!,B>?H1",``$B%P`^$]@```$F)QDB)
MQ^A`(P``2(7`#X32````2(G#3(V]\/[__^LO9BX/'X0``````)!,B>_H*",`
M`$R)[^CP(@``3(GWZ`@C``!(B<-(A<`/A)<```!(@\,8OJT:(`!(B=_HJR$`
M`(7`=->^_1P@`$B)W^B:(0``A<!TQDR)Y^AN(0``28G%2(G?Z&,A``!$`>B#
MP`)(8_CH!2$``$F)Q;[)'"``2(G'3(GB2(G9,<#HS2```$R)[TR)_NAB(0``
M@_C_#X1I____#[>%"/___R4`\```/0!````/A5+___],B>_HVO[__^E-____
M3(GWZ'TB``!,B>?HA2(``$B+!2Y,``!(.T70=1)(@<3H````6T%<05U!7D%?
M7</HH2```)!52(GE05=!5D%505132('L"`0``$B+!?5+``!(B470BSW;2P``
MZ/8?``"*F+@```"+/<I+``#HY1\``(B8N0```$B+'8A'``!(A=MT>KB:'"``
M9BX/'X0```````\?0``/M@B$R70+@/D]=`9(@\`!Z^Y,BSM-A?]T3;F:'"``
M*<A,8_!(@\,(ZQ)F#Q]$``!,BSM(@\,(387_="N^FAP@`$R)_TR)\N@$(```
MA<!UX$.`/#<]==E#@'PW`3%U"$.`?#<"`'0%Z$3E__^+/2Y+``#H21\``+[[
M'"``2(G'N@$```"Y`P```.B"(0``2(7`=#-(B<.+/01+``#H'Q\``$B+2Q!(
MBS&Z$QP@`$B)Q^AK(0``2(M#$$B+`/9`#D`/A8X"``"+/=1*``#H[QX``+X1
M'"``2(G'N@$```"Y`P```.@H(0``2(7`#X0W`0``28G'3(LM=48``$V%[71R
MN(T<(`!F+@\?A```````D`^V"(3)=`N`^3UT!DB#P`'K[DF+70!(A=MT1[F-
M'"``*<A,8^!)@\4(13'VZP]FD$F+70!)@\4(2(7;="B^C1P@`$B)WTR)XNCS
M'@``A<!UWT*`/",]==A.C30C28/&`>L#13'VBSTE2@``Z$`>``!)BT\02(L9
M387V#X6*````2(L%Z4D``$R+,$B-M=#[__^_"QL@`+K_`P``Z&`>``"%P'Y;
MC4C_2&/)@+P-T/O__P!U#8/X`GQ&N?____](`<A!B<=(C;W0^___OB\```!,
MB?KH2"```$B%P'0BBSVM20``Z,@=``!(C970^___2(G'2(G>3(GYZ#,@``#K
M&8L]BTD``.BF'0``2(G'2(G>3(GRZ/@?``"+/7))``#HC1T``$B)PXL]9$D`
M`.A_'0``OIE8(`!(B<>Z`0```.C]'P``NM$<(`!(B=](B<;HO1\``(L]-TD`
M`.A2'0``QH"Y`````$R+/?1$``!-A?]T=[@!'"``9BX/'X0```````^V"(3)
M=`N`^3UT!DB#P`'K[DF+'TB%VW1.N0$<(``IR$QC\$F#QPCK$F8/'T0``$F+
M'TF#QPA(A=MT++X!'"``2(G?3(GRZ'0=``"%P'7@0H`\,SUUV4J-/#-(@\<!
M2(D]DD@``.LF2,<%A4@```````!(BSUV2```Z-'N__](B<=(B05O2```2(7`
M=%J^P`$``.@8'@``C4@!@_D"<@6#^!%U3TB+!71(``!(.T70=3%(@<0(!```
M6T%<05U!7D%?7<.+/49(``#H81P``$B+2Q!(BS%(B<?H\AX``.E3_?__Z,@<
M``"_ZAH@`#'`Z.P>``!(BPWU1P``2(LQ2(L5\T<``+]N&R``B<$QP.C-'@``
M9BX/'X0```````\?`%5(B>5!5T%6055!5%-(@^PH2(L%Z$<``$B)1=")?<Q(
MB77`2(E5N$B-?<Q(C77`2(U5N.B8'@``O\"U(`"^T+4@`+K0M2``Z+0>``"`
M/?5'````=2_HMAX``$B)!7]'``!(A<`/A"(#``!(B<?HKAX``(L]>$<``.B3
M&P``QH!Q"0```(L]9D<``.B!&P``@(@B!````HL]5$<``.AO&P``@(@B!```
M`4AC1<Q$C7`#2(T\Q2````#H<QX``$B)!0Q'``!(BTW`2(L12(D02,=`"(A8
M(`!(BQ7+0```2(E0$$C'0!B+6"``BU7,O@0```"#^@(/C/T```!,C4K_NP0`
M``"^`0```$F#^00/@LX```!,C4`@2(T\T4DY^',53(T$T$F#P!A(C7D(23GX
M#X>L````3(G.2(/F_$B-?OQ(B?M(P>L"2(/#`4&)V$&#X`%(A?\/A!T"``!,
MB<=(*=\QVV8N#Q^$```````/'T``#Q!$V0@/$$S9&`\11-@@#Q%,V#`/$$39
M*`\03-DX#Q%$V$`/$4S84$B#PPA(@\<"=<Y-A<!T'TB-/-T`````2(//"`\0
M!#D/$$PY$`\11-@@#Q%,V#!(C5X$23GQ="9(@\X!9BX/'X0```````\?`$B+
M//%(B3S82(/#`4B#Q@%(.=9RZXG>2,<$\`````!(BSW:10``OH":(`!$B?)(
MB<%%,<#H)QT``$&)QH7`=0](BSVY10``Z"0=``!!B<9(BSVJ10``Z"4=``!,
MBR5^00``387D=&:X+AP@``\?0``/M@B$R70+@/D]=`9(@\`!Z^Y-BRPD387M
M=$*Y+AP@`"G(3&/X28U<)`CK$`\?0`!,BRM(@\,(387M="&^+AP@`$R)[TR)
M^N@$&@``A<!UX$.`?#T`/778Z9H```!(BSTD10``2(7_=`KHDO;__^F$````
M387D='2X`1P@``\?``^V"(3)=`N`^3UT!DB#P`'K[DF+'"1(A=MT4;D!'"``
M*<A,8_A)@\0(ZQ(/'T0``$F+'"1)@\0(2(7;="^^`1P@`$B)WTR)^NB#&0``
MA<!UWT*`/#L]==A*C3P[2(/'`4B)/:%$``#I??___TC'!9%$````````2(L]
MDD0``.@='```Z"@<``!(BP6A1```2#M%T'4B1(GP2(/$*%M!7$%=05Y!7UW#
M,=M-A<`/A27^___I/_[__^@$&0``OP$```#H:A@``&8N#Q^$``````!52(GE
MBSU&1```Z&$8``"+/3M$``#H5A@``+[$&R``N@"S(`"YP%@@`$B)Q^A?&```
MBST91```Z#08``"^KQL@`+K0DB``N?(<(`!!N/(<(`!(B<=%,<E=Z9,;``#,
MS,Q52(GEOX````#H8A@```\H!5N^__\/$0`/*`5!OO__#Q%`$+GPX=+#2(E(
M(,=`>``````/5\`/$4`H7<,/'T``54B)Y4%7059!54%44U!!B==)B?5)B?Y(
M8\)(BW<H2(M/,(T4QD@Y\G,(2(/!`4F)3C!)B58H2,'H'4@!R$F)1C!)8T9X
M2(7`=$:Y0````"G!1#GY00]/STF-/`9(@\<X3&/A3(GN3(GBZ-(7``!!BT9X
M1`'@08E&>(/X0`^%?````$T!Y44IYTR)]^B`````38UF.$&#_T!\3&8/'T0`
M`$$/$$4`00\031!!#Q!5($$/$%TP00\17"0P00\15"0@00\13"0000\1!"1)
M@\5`08U?P$R)]^@U````08/_?T&)WW^\ZP-$B?M,8_M,B>=,B>Y,B?KH1A<`
M`$6)?GA(@\0(6T%<05U!7D%?7<,/'P!52(GE05=!5D%505132('LJ`(``$B+
M!95"``!(B4702,?`_O___V8N#Q^$``````!(BTR'0(G*P>(8B<[!Y@B!Y@``
M_P!("=9(B<I(P>H(@>(`_P``2`GR2(G.2,'N&$`/MMY("=-(B9S%8/W__TB)
MRDC!ZB#!XAB!Y@``_P!(B<M(P>LH@>,`_P``2,'I.$@)V4@)\4@)T4B)C,5H
M_?__2(/``DB#^`YRAC'`#Q]``$B+C,60_?__2#.,Q;C]__](,XS%8/W__T@S
MC,50_?__C10)2,'I'PG12(F,Q=#]__](@\`!2(/X0'7%3(L_2(M'"$B+=Q#S
M#V]'&$V)^TB)PDC!XAY)B<))P>H"20G218G612'^3(GZ38GY3(GY2,'A!4G!
MZQM)"<M(B?%(B84X_?__2"'!2/?09D@/?L-(B9U`_?__2"'82`G(2(N-4/W_
M_V8/<,A.9D@/?LM,`=M(`<-,C00928'`F7F"6D6)PT6)Q$'!Y`5,B=E(P>D;
M20G,1(MMR$4!_4CWTDB)\$B)M4C]__]((?),"?)(`Y5`_?__2`.56/W__TD!
MU$F!Q)EY@EI%B>9)P>$>2<'O`DT)ST2)^D0APD2)X\'C!4R)]DC![AM("?-$
MB<;WUD0AU@G62(N58/W__T@!PD@!\D@!VDB!PIEY@EI!B=%!P>`>2<'K`DT)
MV(G6P>8%3(G+2,'K&T@)WD2)XT0APT2)X??11"'Y"=E,`Y5H_?__20'*3`'6
M2('&F7F"6D&)\D'!Y!Y)P>X"30GTB?/!XP5,B=%(P>D;2`G+08G312'CB='W
MT40AP40)V4P#O7#]__])`<]-C30?28'&F7F"6D6)\\'B'DG!Z0),"<I$B?'!
MX05,B=A(P>@;2`G!08GQ02'1B?#WT$0AX$0)R$P#A7C]__])`<!-C3P(28''
MF7F"6D6)^,'F'DG!Z@),"=9%B?E!P>$%3(G!2,'I&TD)R42)\2'Q1(GS]],A
MTTP#I8#]__\)RTD!W$T!S$F!Q)EY@EI%B>%!P>8>2<'K`DT)WD6)XD'!X@5,
MB<M(P>L;20G:1(G[1"'S1(GX]]`A\`G82`.5B/W__T@!PDZ-'!))@<.9>8):
M18G:0<'G'DG!Z`)-"<=$B=O!XP5,B=!(P>@;2`G#1(G@1"'X1(GA]]%$(?$)
MP4@#M9#]__](`<Y(`=Y(@<:9>8):08GP0<'D'DG!Z0)-"<R)\,'@!4R)P4C!
MZ1M("<A$B=E$(>%$B=KWTD0A^@G*3`.UF/W__TD!UDD!QDF!QIEY@EI%B?%!
MP>,>2<'J`DT)TT2)\,'@!4R)R4C!Z1M("<B)\40AV8GR]])$(>),`[V@_?__
M"<I)`==)`<=)@<>9>8):18GZP>8>2<'H`DP)QD2)^<'A!4R)TDC!ZAM("=%$
MB?(A\D2)\_?31"';"=-,`Z6H_?__20'<20',28'$F7F"6D6)X$'!YAY)P>D"
M30G.1(GBP>(%3(G#2,'K&T@)VD2)^T0A\T2)^/?0(?`)V$P#G;#]__])`<-)
M`=-)@<.9>8):18G90<'G'DG!Z@)-"==$B=O!XP5,B<A(P>@;2`G#1(G@1"'X
M1(GA]]%$(?$)P4@#M;C]__](`<Y(`=Y(@<:9>8):08GR0<'D'DG!Z`)-"<2)
M\,'@!4R)T4C!Z1M("<A$B=E$(>%$B=KWTD0A^DP#M<#]__\)RDD!UDD!QDF!
MQIEY@EI%B?!!P>,>2<'I`DT)RT2)\,'@!4R)P4C!Z1M("<B)\40AV8GR]])$
M(>()RDP#O<C]__])`==)`<=)@<>9>8):18GYP>8>2<'J`DP)UD2)^<'A!4R)
MRDC!ZAM("=%$B?(A\D2)\_?31"';"=-,`Z70_?__20'<28T4#$B!PIEY@EI!
MB=)!P>8>2<'H`DT)QHG1P>$%3(G32,'K&T@)V42)^T0A\T2)^/?0(?`)V$P#
MG=C]__])`<-)C1P+2('#F7F"6D&)V$'!YQY)P>D"30G/3(G!2,'A!4R)P$C!
MZ!M("<A!B=%%(?F)T??11"'Q2`.UX/W__T0)R4@!SDR-)`9)@<29>8):18GA
MP>(>2<'J`DP)TDR)R$C!X`5,B<E(P>D;2`G!08G202':B=CWT$0A^$0)T$P#
MM>C]__])`<9)C00.2`69>8):08G"P>,>2<'H`DP)PTV)T$G!X`5-B=-)P>L;
M30G#2(G92#'13`.]\/W__TPQX4D!ST^-!!])@<"AZ]EN18G#0<'D'DG!Z0)-
M"<Q-B=E)P>$%3(G92,'I&TP)R4R)YD@QWD@QQD@#E?C]__](`?)(`=%(@<&A
MZ]EN08G)P>`>2<'J`DP)T$R)RDC!X@5,B<Y(P>X;2`G62(G"3#'B3#'"2`.=
M`/[__T@!TTB-%#-(@<*AZ]EN08G20<'@'DG!ZP)-"=A,B=9(P>8%3(G32,'K
M&T@)\TR)QD@QQD@QSDP#I0C^__])`?1)C30<2('&H>O9;D&)\\'A'DG!Z0),
M"<E-B=E)P>$%38G>2<'N&TT)SDB)RTPQPT@#A1#^__](,=-(`=A*C1PP2('#
MH>O9;D&)V<'B'DG!Z@),"=)-B<I)P>(%38G.2<'N&TT)UDB)T$@QR$@Q\$P#
MA1C^__])`<!+C00P2`6AZ]EN08G`P>8>2<'K`DP)WDV)PDG!X@5-B<-)P>L;
M30G328GR23'223':2`.-(/[__TP!T4P!V4B!P:'KV6Y!B<K!XQY)P>D"3`G+
M38G12<'A!4V)TTG!ZQM-"<M)B=E),?%),<%(`Y4H_O__3`'*3`':2('"H>O9
M;D&)T<'@'DG!Z`),"<!-B<A)P>`%38G+2<'K&TT)PTF)P$DQV$@#M3#^__])
M,<A,`<9,`=Y(@<:AZ]EN08GPP>$>2<'J`DP)T4V)PDG!X@5-B<-)P>L;30G3
M28G*23'"23'22`.=./[__TP!TTP!VTB!PZ'KV6Y!B=K!XAY)P>D"3`G*38G1
M2<'A!4V)TTG!ZQM-"<M)B=%),<E),?%(`X5`_O__3`'(3`'82`6AZ]EN08G!
MP>8>2<'H`DP)QDV)R$G!X`5-B<M)P>L;30G#28GP23'023'82`.-2/[__TP!
MP4P!V4B!P:'KV6Y!B<C!XQY)P>H"3`G338G"2<'B!4V)PTG!ZQM-"=-)B=I)
M,?)(`Y50_O__23'"3`'23`':2('"H>O9;D&)TL'@'DG!Z0),"<A-B=%)P>$%
M38G32<'K&TT)RTF)P4DQV4DQR4@#M5C^__],`<Y.C0P>28'!H>O9;D6)SL'A
M'DG!Z`),"<%-B?!)P>`%38GS2<'K&TT)PTB)SD@QQD@QUD@#G6#^__](`?-)
M`=M)@<.AZ]EN18G8P>(>2<'J`DP)TDR)QDC!Y@5,B<-(P>L;2`GS2(G62#'.
M3#'.2`.%:/[__T@!\$@!V$@%H>O9;D&)PD'!X1Y)P>X"30GQ3(G62,'F!4R)
MTTC!ZQM("?-,B<Y(,=9(`XUP_O__3#'>2`'Q3(TD&4F!Q*'KV6Y%B>9!P>,>
M2<'H`DT)PTR)]DC!Y@5,B?%(P>D;2`GQ3(G>3#'.2#'&2`.5>/[__T@!\DR-
M/`I)@<>AZ]EN18GXP>`>2<'J`DP)T$2)^<'A!4R)PDC!ZAM("=%(B<),,=I,
M,?),`XV`_O__20'128T<"4B!PZ'KV6Y!B=I!P>0>2<'N`DT)]$&)V4'!X05,
MB=%(P>D;20G)3(GA2#'!3#'!3`.=B/[__TD!RTN-#`M(@<&AZ]EN08G+0<'G
M'DG!Z`)-"<=!B<A!P>`%3(G>2,'N&TD)\$6)^44)X4$AV42)_D0AYD0)SD@#
MA9#^__](`?!,`<!!N=R\&X],`<A!B<#!XQY)P>H"3`G308G"0<'B!4R)QDC!
M[AM)"?)!B=Y%"?Y!(<Z)WD0A_D0)]DP#I9C^__])`?1-`=1-`<Q%B>+!X1Y)
MP>L"3`G918GC0<'C!4R)UDC![AM)"?-!B<Y!"=Y!(<:)SB'>1`GV3`.]H/[_
M_TD!]TT!WTT!ST6)^\'@'DG!Z`),"<!%B?A!P>`%3(G>2,'N&TD)\$&)QD$)
MSD4AYHG&(<Y$"?9(`YVH_O__2`'S3`'#3`'+08G80<'D'DG!Z@)-"=1!B=I!
MP>(%3(G&2,'N&TD)\D6)YD$)QD4A_D2)YB'&1`GV2`.-L/[__T@!\4P!T4P!
MR4&)RD'!YQY)P>L"30G?08G+0<'C!4R)UDC![AM)"?-%B?Y%">9!(=Y$B?Y$
M(>9$"?9(`X6X_O__2`'P3`'83`'(08G#P>,>2<'H`DP)PT&)P$'!X`5,B=Y(
MP>X;20GP08G>10G^02'.B=Y$(?Y$"?9,`Z7`_O__20'T30'$30',18G@P>$>
M2<'J`DP)T46)XD'!X@5,B<9(P>X;20GR08G.00G>02'&B<XAWD0)]DP#O<C^
M__])`?=-`==-`<]%B?K!X!Y)P>L"3`G818G[0<'C!4R)UDC![AM)"?-!B<9!
M"<Y%(>:)QB'.1`GV2`.=T/[__T@!\TP!VTP!RT&)VT'!Y!Y)P>@"30G$08G8
M0<'@!4R)WDC![AM)"?!%B>9!"<9%(?Y$B>8AQD0)]D@#C=C^__](`?%,`<%,
M`<E!B<A!P><>2<'J`DT)UT&)RD'!X@5,B<9(P>X;20GR18G^10GF02'>1(G^
M1"'F1`GV2`.%X/[__T@!\$P!T$P!R$&)PL'C'DG!ZP),"=M!B<-!P>,%3(G6
M2,'N&TD)\T&)WD4)_D$ASHG>1"'^1`GV3`.EZ/[__TD!]$T!W$T!S$6)X\'A
M'DG!Z`),"<%%B>!!P>`%3(G>2,'N&TD)\$&)SD$)WD$AQHG.(=Y$"?9,`[WP
M_O__20'W30''30'/18GXP>`>2<'J`DP)T$6)^D'!X@5,B<9(P>X;20GR08G&
M00G.12'FB<8ASD0)]D@#G?C^__](`?-,`=-,`<M!B=I!P>0>2<'K`DT)W$&)
MVT'!XP5,B=9(P>X;20GS18GF00G&12'^1(GF(<9$"?9(`XT`____2`'Q3`'9
M3`')08G+0<'G'DG!Z`)-"<=!B<A!P>`%3(G>2,'N&TD)\$6)_D4)YD$AWD2)
M_D0AYD0)]D@#A0C___](`?!,`<!,`<A!B<#!XQY)P>H"3`G308G"0<'B!4R)
MQDC![AM)"?)!B=Y%"?Y!(<Z)WD0A_D0)]DP#I1#___])`?1-`=1-`<Q%B>+!
MX1Y)P>L"3`G918GC0<'C!4R)UDC![AM)"?-!B<Y!"=Y!(<:)SB'>1`GV3`.]
M&/___TD!]TT!WTT!ST6)^\'@'DG!Z`),"<!-B=A)P>`%38G>2<'N&TT)QD&)
MP$$)R$4AX(G&(<Y$"<9(`YT@____2`'S3`'S3`'+08G80<'D'DG!Z@)-"=1-
MB<))P>(%38G&2<'N&TT)UD6)XD$)PD4A^D2)YB'&1`G62`.-*/___T@!\4P!
M\4P!R4&)RD'!YQY)P>L"30G?38G32<'C!4R)UDC![AM,"=Y)@<'Z!$<[3(N=
M,/___TT!RTD!PTR)^$PQX$@QV$D!PTD!\T6)WL'C'DG!Z`),"<-,B?!(P>`%
M3(GV2,'N&T@)QDB+A3C___],`<A,`>!(B=I,,?I(,<I(`=!(`?!!B<3!X1Y)
MP>H"3`G13(GF2,'F!4R)XDC!ZAM("?),BX5`____30'(30'X2(G.2#'>3#'>
M20'P20'018G"0<'C'DG![@)-"?-,B=9(P>8%3(G22,'J&T@)\DB+M4C___],
M`<Y(`=Y,B=M(,<M(,<-(`=Y(`=9!B?;!X!Y)P>P"3`G@3(GR2,'B!4R)\TC!
MZQM("=-,BZ50____30',20',2(G!3#'93#'!20',20'<18GG0<'@'DG!Z@)-
M"=!,B?E(P>$%38GZ2<'J&TD)RDB+C5C___],`<E,`=E,B<-(,<-(,?-(`=E,
M`=%!B<K!YAY)P>X"3`GV38G32<'C!4R)TTC!ZQM,"=M,BYU@____30'+20'#
M2(GP3#'`3#'@20'#20';18G>0<'D'DG![P)-"?Q,B?!(P>`%3(GS2,'K&T@)
MPTB+A6C___],`<A,`<!,B>)(,?)(,<I(`=!(`=A!B<#!X1Y)P>H"3`G13(G#
M2,'C!4R)PDC!ZAM("=I,B[UP____30'/20'W2(G.3#'F3#'>20'W20'718GZ
M0<'C'DG![@)-"?-,B=9(P>8%38G62<'N&TD)]DB+M7C___],`<Y,`>9,B=I(
M,<I(,<)(`=9,`?9!B?;!X!Y)P>@"3`G`3(GR2,'B!4V)\$G!Z!M)"=!,BV6`
M30',20',2(G!3#'93#'Y20',30'$1(GB0<'G'DG!Z@)-"==(B=%(P>$%28G2
M2<'J&TD)RDB+38A,`<E,`=E,B?M(,<-(,?-(`=E,`=%!B<K!YAY)P>X"3`GV
M38G32<'C!4V)UDG![AM-"=Y,BT6030'(20'`2(GP3#'X3#'@20'`30'P18G&
M0<'D'DC!Z@))"=1,B?)(P>(%3(GP2,'H&T@)T$R+79A-`<M-`?M,B>)(,?)(
M,<I)`=-)`<-%B=_!X1Y)P>H"3`G13(GX2,'@!4R)^DC!ZAM("<)(BT6@3`'(
M2`'P2(G.3#'F3#'&2`'P2`'008G"0<'@'DG![@)-"?!,B=9(P>8%3(G22,'J
M&T@)\DB+=:A,`<Y,`>9,B<-(,<M,,=M(`=Y(`=9(BU6X3`'*3`'"18G&0<'C
M'DG![P)-"?M!B?!%,=Y!,<;!X!Y)P>H"3`G02(G#3#';2#'SP>8%9DD/;LA)
MP>@;00GP`TVP1`'Q1`'!@<'6P6+*28G(2<'@!4B)SDC![AM,"<9(`=I(`?)!
MB=")T\'C!4R)QDC![AM("?-F2`]NT68/;-%F#V_*9@]S\1YF#]L-(JG__V8/
M<]("9@_KRDP#3<!F#W#13DT!V69)#W[22#'!3#'120')20'91(G)2(NU./W_
M_T0!SD2)R\'C!4C!Z1L)V69(#W[+,=-$,=/!XAY)P>@"00G01`'H`=@!R`76
MP6+*2(D'2(EW"$B+A4C]__]$`<!(B4<09@_4R&8/VPV2J/__\P]_3QA(BP4&
M+@``2#M%T'422('$J`(``%M!7$%=05Y!7UW#Z'D"``!F#Q^$``````!52(GE
M05=!5D%44TB)\TF)_DB+5BA,BV8P28G7P>H#@^(_QD06.(!(C3P62(/'.8/Z
M.'(K@_(_,?;H0@4``$B)W^CJZO__#U?`#Q%#6`\10T@/$4,X2,=#:`````#K
M$;@W````*=!(8]`Q]N@0!0``3(GA3(G@2,'H&(A#<$R)X$C!Z!"(0W&(:W*(
M2W-,B?E,B?A(P>@8B$-T3(GX2,'H$(A#=8AK=HA+=TB)W^A^ZO__BD,#08@&
MBD,"08A&`8I#`4&(1@**`T&(1@.*0PM!B$8$BD,*08A&!8I#"4&(1@:*0PA!
MB$8'BD,308A&"(I#$D&(1@F*0Q%!B$8*BD,008A&"XI#&T&(1@R*0QI!B$8-
MBD,908A&#HI#&$&(1@^*0R-!B$80BD,B08A&$8I#(4&(1A**0R!!B$832(G?
M6T%<05Y!7UWIE`(``,S,S,Q52(GE4U!(BP4S%```2(/X_W0<NXC&(``/'X0`
M`````/_02(L#2(/#^$B#^/]U\4B#Q`A;7</,S$B#[`CHO[[__^BZ____2(/$
M",,`2(/L".AKOO__2(/$",,```````#_->HE``#_)>PE```/'T``_R7J)0``
M:`````#IX/____\EXB4``&@!````Z=#_____)=HE``!H`@```.G`_____R72
M)0``:`,```#IL/____\ERB4``&@$````Z:#_____)<(E``!H!0```.F0____
M_R6Z)0``:`8```#I@/____\ELB4``&@'````Z7#_____):HE``!H"````.E@
M_____R6B)0``:`D```#I4/____\EFB4``&@*````Z4#_____)9(E``!H"P``
M`.DP_____R6*)0``:`P```#I(/____\E@B4``&@-````Z1#_____)7HE``!H
M#@```.D`_____R5R)0``:`\```#I\/[___\E:B4``&@0````Z>#^____)6(E
M``!H$0```.G0_O___R5:)0``:!(```#IP/[___\E4B4``&@3````Z;#^____
M)4HE``!H%````.F@_O___R5")0``:!4```#ID/[___\E.B4``&@6````Z8#^
M____)3(E``!H%P```.EP_O___R4J)0``:!@```#I8/[___\E(B4``&@9````
MZ5#^____)1HE``!H&@```.E`_O___R42)0``:!L```#I,/[___\E"B4``&@<
M````Z2#^____)0(E``!H'0```.D0_O___R7Z)```:!X```#I`/[___\E\B0`
M`&@?````Z?#]____)>HD``!H(````.G@_?___R7B)```:"$```#IT/W___\E
MVB0``&@B````Z<#]____)=(D``!H(P```.FP_?___R7*)```:"0```#IH/W_
M__\EPB0``&@E````Z9#]____);HD``!H)@```.F`_?___R6R)```:"<```#I
M</W___\EJB0``&@H````Z6#]____):(D``!H*0```.E0_?___R6:)```:"H`
M``#I0/W___\EDB0``&@K````Z3#]____)8HD``!H+````.D@_?___R6")```
M:"T```#I$/W___\E>B0``&@N````Z0#]____)7(D``!H+P```.GP_/___R5J
M)```:#````#IX/S___\E8B0``&@Q````Z=#\____)5HD``!H,@```.G`_/__
M_R52)```:#,```#IL/S___\E2B0``&@T````Z:#\____)4(D``!H-0```.F0
M_/___R4Z)```:#8```#I@/S___\E,B0``&@W````Z7#\____)2HD``!H.```
M`.E@_/___R4B)```:#D```#I4/S___\E&B0``&@Z````Z4#\____)1(D``!H
M.P```.DP_/___R4*)```:#P```#I(/S_____________``````````#_____
M_____P`````````````````````=`````````.4#`````````0`````````)
M!`````````$`````````O0,````````!`````````!D$`````````0``````
M```C!`````````$`````````,00````````!`````````-(#````````%0``
M``````````````````<`````````,!0@```````(`````````&``````````
M"0`````````8`````````!<`````````D!0@```````"`````````+@%````
M`````P````````"8V"```````!0`````````!P`````````&``````````@#
M(```````"P`````````8``````````4`````````[`\@```````*````````
M`#X$````````]?[_;P````!(#"````````0`````````)`T@```````,````
M`````(BR(```````#0````````"<LB```````/#__V\`````2`L@``````#^
M__]O`````/@+(```````____;P`````"````````````````````````````
M``#R'"``````````````````J,8@```````````````````=(```````____
M_P````"XQB````````````````````````````#&LB```````-:R(```````
MYK(@``````#VLB````````:S(```````%K,@```````FLR```````#:S(```
M````1K,@``````!6LR```````&:S(```````=K,@``````"&LR```````):S
M(```````IK,@``````"VLR```````,:S(```````UK,@``````#FLR``````
M`/:S(```````!K0@```````6M"```````":T(```````-K0@``````!&M"``
M`````%:T(```````9K0@``````!VM"```````(:T(```````EK0@``````"F
MM"```````+:T(```````QK0@``````#6M"```````.:T(```````]K0@````
M```&M2```````!:U(```````)K4@```````VM2```````$:U(```````5K4@
M``````!FM2```````':U(```````AK4@``````"6M2```````*:U(```````
MMK4@``````#&M2```````-:U(```````YK4@``````#VM2````````:V(```
M````%K8@```````FMB```````#:V(```````1K8@``````!6MB```````&:V
M(```````=K8@``````"&MB```````"1&<F5E0E-$.B!R96QE;F<O,3(N,B]L
M:6(O8W-U+V%M9#8T+W)E;&]C+F,@,S,Y,S4Q(#(P,3@M,3`M,3,@,C,Z-3(Z
M-35:(&MI8B`D`"1&<F5E0E-$.B!R96QE;F<O,3(N,B]L:6(O8W-U+V%M9#8T
M+V-R=#$N8R`S,SDS-3$@,C`Q."TQ,"TQ,R`R,SHU,CHU-5H@:VEB("0`)$9R
M965"4T0Z(')E;&5N9R\Q,BXR+VQI8B]C<W4O8V]M;6]N+VEG;F]R95]I;FET
M+F,@,S,Y,S4Q(#(P,3@M,3`M,3,@,C,Z-3(Z-35:(&MI8B`D`"1&<F5E0E-$
M.B!R96QE;F<O,3(N,B]L:6(O8W-U+V%M9#8T+V-R=&DN4R`R,3<Q,#4@,C`Q
M,2TP,2TP-R`Q-CHP-SHU,5H@:VEB("0`1G)E94)31"!C;&%N9R!V97)S:6]N
M(#$P+C`N,2`H9VET0&=I=&AU8BYC;VTZ;&QV;2]L;'9M+7!R;VIE8W0N9VET
M(&QL=FUO<F<M,3`N,"XQ+3`M9V5F,S)C-C$Q86$R*0!,:6YK97(Z($Q,1"`Q
M,"XP+C$@*$9R965"4T0@;&QV;6]R9RTQ,"XP+C$M,"UG968S,F,V,3%A83(M
M,3(P,#`Q,BD`)$9R965"4T0Z(')E;&5N9R\Q,BXR+VQI8B]C<W4O8V]M;6]N
M+V-R=&)R86YD+F,@,S8V.34T(#(P,C`M,3`M,C,@,#`Z,#`Z-3):(&=J8B`D
M```D1G)E94)31#H@<F5L96YG+S$R+C(O;&EB+V-S=2]A;60V-"]C<G1N+E,@
M,C$W,3`U(#(P,3$M,#$M,#<@,38Z,#<Z-3%:(&MI8B`D```N:6YT97)P`"YN
M;W1E+G1A9P`N9'EN<WEM`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N
M9VYU+FAA<V@`+FAA<V@`+F1Y;G-T<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YR
M;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+G1E>'0`+FEN:70`+F9I
M;FD`+G!L=``N8W1O<G,`+F1T;W)S`"YJ8W(`+F1Y;F%M:6,`+F1A=&$`+F=O
M="YP;'0`+F)S<P`N8V]M;65N=``N<VAS=')T86(`````````````````````
M````````````````````````````````````````````````````````````
M```````!`````0````(`````````J`(@``````"H`@```````!4`````````
M```````````!````````````````````"0````<````"`````````,`"(```
M````P`(```````!(````````````````````!````````````````````!,`
M```+`````@`````````(`R````````@#````````0`@````````(`````0``
M``@`````````&``````````;````____;P(`````````2`L@``````!("P``
M`````+```````````P`````````"``````````(`````````*````/[__V\"
M`````````/@+(```````^`L```````!0``````````@````"````!```````
M`````````````#<```#V__]O`@````````!(#"```````$@,````````W```
M```````#``````````@```````````````````!!````!0````(`````````
M)`T@```````D#0```````,@"`````````P`````````$``````````0`````
M````1P````,````"`````````.P/(```````[`\````````^!```````````
M`````````0```````````````````$\````$`````@`````````P%"``````
M`#`4````````8``````````#``````````@`````````&`````````!9````
M!`````(`````````D!0@``````"0%````````+@%`````````P```!<````(
M`````````!@`````````8P````$````R`````````%`:(```````4!H`````
M```P/P``````````````````$````````````````````&L````!`````@``
M``````"`62```````(!9````````S`````````````````````0`````````
M``````````!Y`````0````(`````````4%H@``````!06@```````#P$````
M```````````````(````````````````````@P````$````&`````````)!N
M(```````D%X```````#X0P``````````````````$```````````````````
M`(D````!````!@````````"(LB```````(BB````````$P``````````````
M``````0```````````````````"/`````0````8`````````G+(@``````"<
MH@````````X````````````````````$````````````````````E0````$`
M```&`````````+"R(```````L*(```````#@`P``````````````````$```
M`````````````````)H````!`````P````````"0QB```````)"F````````
M$`````````````````````@```````````````````"A`````0````,`````
M````H,8@``````"@I@```````!`````````````````````(````````````
M````````J`````$````#`````````+#&(```````L*8````````(````````
M````````````"````````````````````*T````&`````P````````"XQB``
M`````+BF````````L`$````````(``````````@`````````$`````````"V
M`````0````,`````````:-@@``````!HJ````````"P`````````````````
M```(````````````````````O`````$````#`````````)C8(```````F*@`
M`````````@``````````````````"````````````````````,4````(````
M`P````````"@VB```````)BJ````````B00``````````````````"``````
M``````````````#*`````0```#````````````````````"8J@```````(("
M```````````````````!``````````$`````````TP````,`````````````
M````````````&JT```````#=`````````````````````0``````````````
$````````
